@@ -1,15 +1,24 @@
 package Dist::Zilla::Plugin::LatestPrereqs;
 BEGIN {
-  $Dist::Zilla::Plugin::LatestPrereqs::VERSION = '0.3';
+  $Dist::Zilla::Plugin::LatestPrereqs::VERSION = '0.4';
 }
 
 use Moose;
 use CPAN;
+use Module::CoreList;
 with 'Dist::Zilla::Role::PrereqSource';
 
+has 'skip_core_modules' => (
+  is      => 'ro',
+  isa     => 'Bool',
+  default => 0,
+);
+
+
 sub register_prereqs {
   my ($self) = @_;
   my $zilla = $self->zilla;
+  my $skip_core = $self->skip_core_modules;
 
   my $prereqs = $zilla->prereqs;
   my $cpan    = _startup_cpan();
@@ -25,6 +34,14 @@ sub register_prereqs {
         ## allow for user defined required version
         next if $prereqs->{$module};
 
+        if ($skip_core) {
+          my $rel = Module::CoreList->first_release($module);
+          if ($rel && $rel <= $]) {
+            $self->log_debug("Skipping core module $module ($rel <= $])");
+            next;
+          }
+        }
+
         ## fetch latest version
         $self->log_debug("Fetch latest version for '$module' from CPAN");
         my $info = $cpan->expand('Module', $module);
@@ -68,14 +85,18 @@ Dist::Zilla::Plugin::LatestPrereqs - adjust prereqs to use latest version availa
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
 At the B<BOTTOM> of your C<dist.ini> file:
 
     [LatestPrereqs]
-
+    
+    ## Optionally skip core modules
+    [LatestPrereqs]
+    skip_core_modules = 1
+    
 
 =head1 DESCRIPTION
 
@@ -98,6 +119,47 @@ To do that it would require updates to the CPAN toolchain. Although I
 would welcome that, this plugin implements the next best thing.
 
 
+=head2 Core modules options
+
+B<NOTE WELL:> this feature should be considered alpha. The interface
+might change in future versions.
+
+The option C<skip_core_modules> can be used to control the behaviour of
+this plugin with core modules (as defined by the
+L<Module::CoreList|Module::CoreList> API).
+
+If set to 1, we will skip forcing the latest version on modules that are
+part of the perl core, version equal or below to the one used to release
+the module.
+
+An example: you have two modules on your C<< [Prereqs] >> list,
+C<Digest::SHA> part of the core since 5.009003, and C<HTTP::Tiny> part
+of the core since 5.013009. With C<skip_core_modules=1>, the following
+will happen:
+
+=over 4
+
+=item * If you release your module using perl 5.008009, both
+C<Digest::SHA> and C<HTTP::Tiny> will be forced to the
+lastest version.
+
+=item * If you release your module using perl 5.012003, the
+C<Digest::SHA> will not be forced to the lastest version, but
+C<HTTP::Tiny> will.
+
+=item * If you release your module using perl 5.014000, both
+C<ExtUtils::MakeMaker> and C<HTTP::Tiny> will not be forced to the
+lastest version.
+
+=back
+
+By default (0) all modules will get the latest version.
+
+Idealy we would make this decision based on the perl version of the
+person that will install your distribution, but for now that is not
+easy to do.
+
+
 =head1 EXTRA REQUIREMENTS
 
 This plugin uses the L<CPAN> module, but hides the output, so make sure
@@ -129,6 +191,8 @@ latest version of the module to be installed.
 A L<Dist::Zilla> plugin that implements what Marcel describes is also
 available, see L<Dist::Zilla::Plugin::MakeMaker::SkipInstall>.
 
+Mike Doherty added the first version of the skip core modules feature.
+
 
 =head1 SEE ALSO
 
